==> kolourpaint_17.12.3.orig.tar.xz: kolourpaint-17.12.3/tools/flow/kpToolFlowPixmapBase.h <==

// REFACTOR: Rename to kpAbstractFlowImageTool, and use kpImage instead of QPixmap

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_FLOW_PIXMAP_BASE_H
#define KP_TOOL_FLOW_PIXMAP_BASE_H


#include "kpToolFlowBase.h"


/**
 * @short Abstract base call for all continuous tools that draw pixmaps
 * (e.g. Brush, Eraser).
 *
 * @author Clarence Dang <dang@kde.org>
 */
class kpToolFlowPixmapBase : public kpToolFlowBase
{
Q_OBJECT

public:
    kpToolFlowPixmapBase (const QString &text, const QString &description,
               int key,
               kpToolEnvironment *environ, QObject *parent, const QString &name);

protected:
    QRect drawLine (const QPoint &thisPoint, const QPoint &lastPoint) Q_DECL_OVERRIDE;
};


#endif  // KP_TOOL_FLOW_PIXMAP_BASE_H

==> kolourpaint-18.08.3.tar.xz: kolourpaint-18.08.3/tools/flow/kpToolFlowPixmapBase.h <==

// REFACTOR: Rename to kpAbstractFlowImageTool, and use kpImage instead of QPixmap

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_FLOW_PIXMAP_BASE_H
#define KP_TOOL_FLOW_PIXMAP_BASE_H


#include "kpToolFlowBase.h"


/**
 * @short Abstract base call for all continuous tools that draw pixmaps
 * (e.g. Brush, Eraser).
 *
 * @author Clarence Dang <dang@kde.org>
 */
class kpToolFlowPixmapBase : public kpToolFlowBase
{
Q_OBJECT

public:
    kpToolFlowPixmapBase (const QString &text, const QString &description,
               int key,
               kpToolEnvironment *environ, QObject *parent, const QString &name);

protected:
    QRect drawLine (const QPoint &thisPoint, const QPoint &lastPoint) override;
};


#endif  // KP_TOOL_FLOW_PIXMAP_BASE_H
